rm(list=ls(all=TRUE))
library(foreign)
library(rjags)
library(fmsb)
library(plotrix)
library(ggplot2)
library(reshape)

#Uploading the information
data<-read.dta("/Users/Cantu/Documents/Yo/Proyectos/Elecciones2012/PollOfPolls/Data.dta")

#Creating variables with the adequate format
#Four candidates:
#Enrique Peña Nieto (PRI): epn
#Andrés Manuel López Obrador (PRD): amlo
#Josefina Vazquez Mota (PAN): jvm
#Gabriel Quadri (PANAL):gqt

data$size<-as.numeric(data$size)
data$error<-as.numeric(data$error)
data$epn<-as.numeric(data$epn)
data$jvm<-as.numeric(data$jvm)
data$amlo<-as.numeric(data$amlo)
data$gqt<-as.numeric(data$gqt)
data$epngross<-as.numeric(data$epngross)
data$jvmgross<-as.numeric(data$jvmgross)
data$amlogross<-as.numeric(data$amlogross)
data$gqtgross<-as.numeric(data$gqtgross)
data$noanswer<-as.numeric(data$noanswer)

data$date<-as.Date(data$date, origin="1960-10-01")
data$pollsterID<-as.integer(as.factor(data$pollster))

data$votosepn<-round(data$epn*data$size,0)
data$votosjvm<-round(data$jvm*data$size,0)
data$votosamlo<-round(data$amlo*data$size,0)
data$votosgqt<-round(data$gqt*data$size,0)

#First poll is on February 18. We start the priors a day before.
startDate<-as.Date("2012-02-17")
#Indexing days
data$day<-as.numeric(data$date-startDate)+1
#Add five days for the time between the last poll and the election
Time<-max(data$day, na.rm=TRUE)+5
NumberofPollsters<-max(data$pollsterID, na.rm=TRUE)

#missing value is row 98
data <- data[-98, ]

#Loading the model
model.file <- "/Users/Cantu/Dropbox/Polls2012/model2012d2014.bug"

#Loading the data
for.jags <- list("y"=cbind(data$votosepn,data$votosamlo,data$votosjvm, data$votosgqt),
                 "I"=nrow(data), "tiempo"=data$day, "pollsterID"=data$pollsterID, 
                 "T"=Time, "J"=NumberofPollsters, #"sigma"=data$sigma, 
"size"=data$size)


my.model <- jags.model(file=model.file,
                       data=for.jags, n.chains=3)
                       
# We burn in the first iterations.
update(my.model,10000) 
                       
                       
res      <- coda.samples(model=my.model,
                         variable.names=c("alpha","delta"),
                         n.iter=500000,thin=250)
                         
print(summary(res))

plot(res)

#############
summary<-as.table(summary(res)$quantiles)

A<-as.data.frame.matrix(summary[1:(136*4),])

days<-seq(as.Date("2012-02-17"), as.Date("2012-07-01"), "days")

A$days<-rep(days,4)
A$candidate<-c(rep("Peña Nieto",136),rep("López Obrador", 136), rep("Vázquez Mota", 136), rep("Quadri", 136))

A<-A[A$candidate!="Quadri",]

names(A)=c("min","25","median","75","max","days", "candidate")

p<-ggplot(data=A, aes(x=days, y=median, ymin=min, ymax=max, fill=candidate))+
geom_line()+
geom_ribbon(alpha=0.5)+
  theme_bw()+
  ylab("Support")+
  xlab("")
  
B<-data.frame(rep(data$date,4))
B$candidate<-c(rep("López Obrador", 182),rep("Peña Nieto",182), rep("Quadri",182), rep("Vázquez Mota", 182))
B$support<-c(data$amlo, data$epn, data$gqt, data$jvm)
colnames(B)<-c("day", "candidate","support")
B$color<-c(rep("#F0E442", 182), rep("red",182), rep("purple", 182),rep("#56B4E9", 182))
B$pollster<-rep(data$pollster,4)

B<-B[B$candidate!="Quadri",]

  
p<-ggplot()+
geom_line(data=A, aes(x=days, y=median, fill=candidate))+
geom_ribbon(data=A, aes(x=days,  ymin=min, ymax=max, fill=candidate), alpha=0.5)+
  theme_bw()+
  ylab("Support")+
  xlab("")+
  geom_point(data=B, aes(x=day, y=support, colour=candidate, shape=pollster))+ scale_fill_manual( values = c("#F0E442","red","#56B4E9"))+ scale_colour_manual( values = c("#F0E442","red","#56B4E9"))+
  scale_shape_manual(values = 1:13)

  
